InputTarget

Trait InputTarget 

pub trait InputTarget {
    // Required method
    fn resolve_input(self, scope: &Scope) -> Result<HtmlInputElement, JsValue>;
}
A native input handle, or a selector checked to refer to an input. Passing an unrelated element handle is a Rust type error.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl InputTarget for &HtmlInputElement

Source

impl InputTarget for &String

Source

impl InputTarget for &str

Implementors