pub trait InputTarget {
// Required method
fn resolve_input(self, scope: &Scope) -> Result<HtmlInputElement, JsValue>;
}Expand description
A native input handle, or a selector checked to refer to an input. Passing an unrelated element handle is a Rust type error.
Required Methods
fn resolve_input(self, scope: &Scope) -> Result<HtmlInputElement, JsValue>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".